.. kolla-kubernetes documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kolla-kubernetes's documentation!
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   contributing
   installation
   kubernetes-all-in-one
   quickstart
   multi-node
   private-registry
   readme
   usage
   labels

Kolla-Kubernetes Services
=========================

.. toctree::
   :maxdepth: 1

   mariadb-guide
   memcached-guide
   keystone-guide
   dns-guide

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
